@@ -470,7 +470,7 @@ var BaseFileSelectDialog = AdminRESTDialog.extend({
 
 		uploader.bind('Error', function(up, error) {
 			if (error.code != plupload.INIT_ERROR) {
-				alert('Upload failed.');
+				alert(gettext('Upload failed.'));
 			}
 		});
 
@@ -491,7 +491,7 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 
 	defaults: {
 		url: '/api/v1/images.jqgrid-json',
-		width: 480,
+		width: 520,
 		height: 'auto',
 		start_width: 480,
 		start_height: 'auto'
@@ -500,6 +500,7 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 	// override default dialog window
 	init_dialog: function() {
 		// don't call _super, just call init_dialog_success at the end
+		this.uiDialog.dialog('option', 'zIndex', 1200); // set z-index here, because it can't set by _super
 
 		// enhance action button
 		var action_button = this.uiDialog.parent().find(':button:contains("Action")');
@@ -550,12 +551,12 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 				{ name: 'image', index: 'image', width: 120, resizable: false, sortable: false, formatter: thumbnail_formatter },
 				{ name: 'filename', index: 'filename', width: 160, resizable: false },
 				{ name: 'size', index: 'size', width: 80, resizable: false },
-				{ name: 'updated', index: 'updated', width: 120, resizable: false }
+				{ name: 'updated', index: 'updated', width: 160, resizable: false }
 			],
 			rowNum: 50,
 			pager: '#ui-image-select-grid-pager',
 			shrinkToFit: false,
-			width: 480,
+			width: 520,
 			height: 300,
 			sortname: 'updated',
 			sortorder: 'desc',
@@ -598,7 +599,7 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 
 	defaults: {
 		url: '/api/v1/files.jqgrid-json',
-		width: 480,
+		width: 520,
 		height: 'auto',
 		start_width: 480,
 		start_height: 'auto'
@@ -607,6 +608,7 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 	// override default dialog window
 	init_dialog: function() {
 		// don't call _super, just call init_dialog_success at the end
+		this.uiDialog.dialog('option', 'zIndex', 1200); // set z-index here, because it can't set by _super
 
 		// enhance action button
 		var actionButton = this.uiDialog.parent().find(':button:contains("Action")');
@@ -629,7 +631,7 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 		this.file_select_grid = $(document.createElement('table')).attr('id', 'ui-file-select-grid'); // the id attribute is necessary for jqGrid
 		this.file_select_grid_pager = $(document.createElement('div')).attr('id', 'ui-file-select-grid-pager');
 		this.file_select_filter = $(document.createElement('div')).attr('id', 'ui-file-select-filter');
-		this.file_select_filter.append($(document.createElement('label')).attr({ id: 'ui-file-select-filter-label'}).text('Filter by filename'));
+		this.file_select_filter.append($(document.createElement('label')).attr({ id: 'ui-file-select-filter-label'}).text(gettext('Filter by filename')));
 		this.file_select_filter.append($(document.createElement('input')).attr({ id: 'ui-file-select-filter-input', name: 'filter', value: '', type: 'text' }));
 		this.uiDialog.append(this.file_select_filter);
 		this.uiDialog.append(this.file_select_grid);
@@ -650,12 +652,12 @@ Fiber.FileSelectDialog = BaseFileSelectDialog.extend({
 			colModel: [
 				{ name: 'url', index: 'url', hidden: true },
 				{ name: 'filename', index: 'filename', width: 360, resizable: false },
-				{ name: 'updated', index: 'updated', width: 120, resizable: false }
+				{ name: 'updated', index: 'updated', width: 160, resizable: false }
 			],
 			rowNum: 50,
 			pager: '#ui-file-select-grid-pager',
 			shrinkToFit: false,
-			width: 480,
+			width: 520,
 			height: 300,
 			sortname: 'updated',
 			sortorder: 'desc',
@@ -715,6 +717,7 @@ Fiber.PageSelectDialog = AdminRESTDialog.extend({
 	// override default dialog window
 	init_dialog: function() {
 		// don't call _super, just call init_dialog_success at the end
+		this.uiDialog.dialog('option', 'zIndex', 1200); // set z-index here, because it can't set by _super
 
 		// enhance action button
 		var action_button = this.uiDialog.parent().find(':button:contains("Action")');
@@ -725,7 +728,7 @@ Fiber.PageSelectDialog = AdminRESTDialog.extend({
 		action_button.attr('disabled', 'disabled');
 		action_button.addClass('ui-button-disabled ui-state-disabled');
 
-		this.uiDialog.dialog('option', 'title', gettext('Select page'));
+		this.uiDialog.dialog('option', 'title', gettext('Select a page'));
 
 		this.init_dialog_success();
 	},
@@ -784,7 +787,6 @@ var ChangePageFormDialog = ChangeFormDialog.extend({
 
 		this.admin_form.options.before_page_id = this.options.before_page_id;
 		this.admin_form.options.below_page_id = this.options.below_page_id;
-		this.admin_form.options.base_url = this.options.base_url;
 		this.admin_form.set_interaction = function() {
 			if (this.options.before_page_id) {
 				extra_field = $('<input type="hidden" name="before_page_id" />');
@@ -798,10 +800,23 @@ var ChangePageFormDialog = ChangeFormDialog.extend({
 				this.form.append(extra_field);
 			}
 
-			// automatically slugify the title field
-			$('#id_title').attr('autocomplete', 'off');
-			$('#id_title').slugify('#id_url');
+			var $url_field = $('#id_url');
+			var $title_field = $('#id_title');
 
+			// remove autocompletion from title field
+			$title_field.attr('autocomplete', 'off');
+
+			// automatically slugify the title field when the url field is initially empty
+			if (!$url_field.val()) {
+				$title_field.slugify($url_field);
+			}
+
+			// automatically (re)start slugifying the title field when the url field is emptied
+			$url_field.change(function() {
+				if (!$url_field.val()) {
+					$title_field.slugify($url_field);
+				}
+			});
 		};
 	}
 });
@@ -843,8 +858,7 @@ var AddButton = Class.extend({ // TODO: subclass to AddPageButton / AddContentIt
 			params = {
 				url: this.options.add_url,
 				before_page_id: this.options.before_page_id,
-				below_page_id: this.options.parent_id, // TODO: rename below_page_id to parent_id?
-				base_url: this.options.base_url
+				below_page_id: this.options.parent_id // TODO: rename below_page_id to parent_id?
 			};
 
 			new ChangePageFormDialog(params); // TODO: create AddPageFormDialog?
@@ -1246,8 +1260,7 @@ var adminPage = {
 									$('<li><a href="#">'+gettext('Edit')+'</a></li>').click($.proxy(function() {
 										var change_page_form_dialog = new ChangePageFormDialog({
 											url: page_data.url,
-											page_id: page_data.id,
-											base_url: page_data.base_url
+											page_id: page_data.id
 										});
 									}, this))
 								);
@@ -1256,8 +1269,7 @@ var adminPage = {
 									$('<li><a href="#">'+gettext('Add sub page')+'</a></li>').click($.proxy(function() {
 										var add_page_form_dialog = new ChangePageFormDialog({
 											url: page_data.add_url,
-											below_page_id: page_data.id,
-											base_url: page_data.base_url
+											below_page_id: page_data.id
 										});
 									}, this))
 								);
@@ -1468,8 +1480,23 @@ var adminPage = {
 									confirmationDialog.html(gettext('<p>Are you sure you want to delete this item?</p>'));
 								})
 							);
+							if (data.used_on_pages.length >= 1) {
+								var context_submenu_used_on_pages = $('<ul class="ui-context-menu"></ul>');
+
+								$(data.used_on_pages).each(function(index) {
+									context_submenu_used_on_pages.append(
+										$('<li><a href="#">'+data.used_on_pages[index].title+'</a></li>').click(function() {
+											location.href = data.used_on_pages[index].url;
+										})
+									);
+								});
+
+								contextmenu.append(
+									$('<li><a href="#">'+gettext('Used on pages')+'</a></li>').prepend(context_submenu_used_on_pages)
+								);
+							}
+							contextmenu.flyoutmenu().removeClass('ui-corner-all');
 
-							contextmenu.menu().removeClass('ui-corner-all');
 							$(document.body).append(contextmenu);
 							contextmenu.offset({ left: event.pageX, top: event.pageY });
 						}
@@ -1815,15 +1842,24 @@ var FiberItem = Class.extend({
 			params = {
 				before_page_id: this.element_data.id
 			};
-		} else if (this.element_data.type == 'content_item') {
-			params = {
-				before_page_content_item_id: this.element_data.id
-			};
-		}
 
-		this.button = new AddButton(
-			this, params
-		);
+			this.button = new AddButton(
+				this, params
+			);
+		} else if (this.element_data.type == 'content_item') {
+			if (
+				this.element_data.block_name &&
+				this.element_data.page_id
+			) {
+				params = {
+					before_page_content_item_id: this.element_data.page_content_item_id
+				};
+
+				this.button = new AddButton(
+					this, params
+				);
+			}
+		}
 	},
 
 	button_position: function() {
@@ -1974,9 +2010,23 @@ var FiberItem = Class.extend({
 					$.proxy(this.remove_from_page, this)
 				)
 			);
+			if (this.element_data.used_on_pages.length > 1) {
+				var context_submenu_used_on_pages = $('<ul class="ui-context-menu"></ul>');
+				$(this.element_data.used_on_pages).each(function(index, value) {
+					context_submenu_used_on_pages.append(
+						$('<li><a href="#">'+value.title+'</a></li>').click(function() {
+							location.href = value.url;
+						})
+					);
+				});
+
+				contextmenu.append(
+					$('<li><a href="#">'+gettext('Used on pages')+'</a></li>').prepend(context_submenu_used_on_pages)
+				);
+			}
 		}
 
-		contextmenu.menu().removeClass('ui-corner-all');
+		contextmenu.flyoutmenu().removeClass('ui-corner-all');
 		$(document.body).append(contextmenu);
 
 		contextmenu.offset({ left: e.pageX, top: e.pageY });
@@ -2003,8 +2053,7 @@ var FiberItem = Class.extend({
 
 		var changePageFormDialog = new ChangePageFormDialog({
 			url: this.element_data.url,
-			page_id: this.element_data.id,
-			base_url: this.element_data.base_url
+			page_id: this.element_data.id
 		});
 	},
 
